pub enum SourceGeometry {
PlanarArray(PlanarLedArray),
SphericalArray(SphericalLedArray),
SphericalArm(SphericalLedArm),
RotatingArc(RotatingLedArc),
Positions(SourcePositionList),
Directions(DirectionList),
KVectors(KVectorList),
}Expand description
Serializable physical or direct source geometry.
Variants
PlanarArray(PlanarLedArray)
Regular planar LED array.
SphericalArray(SphericalLedArray)
Fixed spherical LED array.
SphericalArm(SphericalLedArm)
Mechanically moved spherical LED arm.
RotatingArc(RotatingLedArc)
LED arc sampled over commanded rotations.
Positions(SourcePositionList)
Arbitrary physical positions.
Directions(DirectionList)
Canonical propagation directions.
KVectors(KVectorList)
Direct transverse vectors.
Implementations
Sourceimpl SourceGeometry
impl SourceGeometry
Sourcepub fn source_count(&self) -> usize
pub fn source_count(&self) -> usize
Returns the number of physical or direct sources before acquisition planning.
Sourcepub fn resolve(&self, optics: &Optics) -> Result<ResolvedSources>
pub fn resolve(&self, optics: &Optics) -> Result<ResolvedSources>
Atomically resolves geometry using the wavelength and media in optics.