pub struct DirectionList { /* private fields */ }Expand description
Wavelength-independent incident propagation directions in sample coordinates.
Unit vectors are the canonical stored and serialized form. Directions must
have non-negative z; the on-axis direction is (0, 0, 1).
Implementations
Sourceimpl DirectionList
impl DirectionList
Sourcepub fn from_unit_vectors(unit_vectors: Vec<[f64; 3]>) -> Result<Self>
pub fn from_unit_vectors(unit_vectors: Vec<[f64; 3]>) -> Result<Self>
Validates and stores already normalized propagation directions.
Sourcepub fn from_vectors(vectors: Vec<[f64; 3]>, normalize: bool) -> Result<Self>
pub fn from_vectors(vectors: Vec<[f64; 3]>, normalize: bool) -> Result<Self>
Stores propagation vectors, optionally normalizing each input vector.
Sourcepub fn from_direction_cosines(values: Vec<[f64; 2]>) -> Result<Self>
pub fn from_direction_cosines(values: Vec<[f64; 2]>) -> Result<Self>
Constructs directions from transverse direction cosines (dx, dy).
Sourcepub fn from_component_angles_radians(values: Vec<[f64; 2]>) -> Result<Self>
pub fn from_component_angles_radians(values: Vec<[f64; 2]>) -> Result<Self>
Constructs directions from independent component angles (theta_x, theta_y) in radians.
Sourcepub fn from_component_angles_degrees(values: Vec<[f64; 2]>) -> Result<Self>
pub fn from_component_angles_degrees(values: Vec<[f64; 2]>) -> Result<Self>
Constructs directions from independent component angles in degrees.
Sourcepub fn from_polar_angles_radians(values: Vec<[f64; 2]>) -> Result<Self>
pub fn from_polar_angles_radians(values: Vec<[f64; 2]>) -> Result<Self>
Constructs directions from polar angle theta and azimuth phi, in radians.
Sourcepub fn from_polar_angles_degrees(values: Vec<[f64; 2]>) -> Result<Self>
pub fn from_polar_angles_degrees(values: Vec<[f64; 2]>) -> Result<Self>
Constructs directions from polar angle theta and azimuth phi, in degrees.
Sourcepub fn source_count(&self) -> usize
pub fn source_count(&self) -> usize
Returns the number of directions.
Sourcepub fn unit_vectors(&self) -> &[[f64; 3]]
pub fn unit_vectors(&self) -> &[[f64; 3]]
Borrows the canonical propagation unit vectors.
Sourcepub fn direction_cosines(&self) -> Vec<[f64; 2]>
pub fn direction_cosines(&self) -> Vec<[f64; 2]>
Allocates transverse direction cosines (dx, dy).
Sourcepub fn component_angles_rad(&self) -> Vec<[f64; 2]>
pub fn component_angles_rad(&self) -> Vec<[f64; 2]>
Allocates independent component angles (asin(dx), asin(dy)) in radians.
Sourcepub fn component_angles_deg(&self) -> Vec<[f64; 2]>
pub fn component_angles_deg(&self) -> Vec<[f64; 2]>
Allocates independent component angles in degrees.
Sourcepub fn polar_angles_rad(&self) -> Vec<[f64; 2]>
pub fn polar_angles_rad(&self) -> Vec<[f64; 2]>
Allocates polar (theta, phi) angles in radians.
Sourcepub fn polar_angles_deg(&self) -> Vec<[f64; 2]>
pub fn polar_angles_deg(&self) -> Vec<[f64; 2]>
Allocates polar (theta, phi) angles in degrees.
Sourcepub fn resolve(&self, optics: &Optics) -> Result<ResolvedSources>
pub fn resolve(&self, optics: &Optics) -> Result<ResolvedSources>
Resolves directions with the illumination wavenumber from optics.