pub struct Illumination { /* private fields */ }Expand description
Complete serializable illumination configuration.
Implementations
Sourceimpl Illumination
impl Illumination
Sourcepub const fn new(
geometry: SourceGeometry,
calibration: SourceCalibration,
acquisition: AcquisitionPlan,
) -> Self
pub const fn new( geometry: SourceGeometry, calibration: SourceCalibration, acquisition: AcquisitionPlan, ) -> Self
Creates a complete configuration from separate source concepts.
Sourcepub fn from_geometry(geometry: impl Into<SourceGeometry>) -> Result<Self>
pub fn from_geometry(geometry: impl Into<SourceGeometry>) -> Result<Self>
Creates unit-power sequential acquisition for every geometry source.
Sourcepub const fn geometry(&self) -> &SourceGeometry
pub const fn geometry(&self) -> &SourceGeometry
Borrows the physical or direct source geometry.
Sourcepub const fn calibration(&self) -> &SourceCalibration
pub const fn calibration(&self) -> &SourceCalibration
Borrows the stable source calibration.
Sourcepub const fn acquisition(&self) -> &AcquisitionPlan
pub const fn acquisition(&self) -> &AcquisitionPlan
Borrows the acquisition structure.
Sourcepub fn with_geometry(self, geometry: impl Into<SourceGeometry>) -> Self
pub fn with_geometry(self, geometry: impl Into<SourceGeometry>) -> Self
Replaces the source geometry while retaining calibration and acquisition state.
Sourcepub fn with_calibration(self, calibration: SourceCalibration) -> Self
pub fn with_calibration(self, calibration: SourceCalibration) -> Self
Replaces stable source-power calibration while retaining geometry and acquisition.
Sourcepub fn with_acquisition(self, acquisition: AcquisitionPlan) -> Self
pub fn with_acquisition(self, acquisition: AcquisitionPlan) -> Self
Replaces sparse acquisition weights and frame gains while retaining source state.
Sourcepub fn resolve(&self, optics: &Optics) -> Result<ResolvedIllumination>
pub fn resolve(&self, optics: &Optics) -> Result<ResolvedIllumination>
Atomically resolves geometry, calibration, acquisition weights, and gains.