pub struct IlluminationFrame {
pub contributions: Vec<SourceContribution>,
pub gain: f64,
}Expand description
Sparse mutually incoherent source contributions and gain for one frame.
Fields
contributions: Vec<SourceContribution>Sparse source contributions. Acquisition construction canonicalizes them.
gain: f64Dimensionless, non-negative intensity gain applied to the summed frame.
Implementations
Sourceimpl IlluminationFrame
impl IlluminationFrame
Sourcepub fn new(contributions: Vec<SourceContribution>, gain: f64) -> Self
pub fn new(contributions: Vec<SourceContribution>, gain: f64) -> Self
Creates a frame for validation and canonicalization by AcquisitionPlan.